/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 18.07.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.authentication;

import javax.security.auth.callback.CallbackHandler;

/**
 * Interface AuthenticationService encapsulates common methods to perform a login.
 * <p/>
 * A AuthenticationService is responsible to create AuthenticationContext instances and perform logins and logouts.
 *
 * @author Marko Reiprecht
 *         Created on 18.07.2008
 * @version $Revision: $
 */
public interface AuthenticationService {

    /**
     * Method creates a new AuthenticationContext.
     * The context will be in state <code>not authenticated</code> and contain an empty Subject.
     *
     * @return AuthenticationContext.
     */
    AuthenticationContext createAuthenticationContext();

    /**
     * Method performs a "anonymous" login. The behavior of this mehtod is implementation dependend.
     * <p/>
     * The semantic is that somebody tries to login without any credentials, so an implementation
     * can throw an error or create an "anonymous" AuthenticationContext.
     *
     * @return AuthenticationContext.
     * @throws AuthenticationException if error occurs.
     */
    AuthenticationContext login() throws AuthenticationException;

    /**
     * Method performs a login.
     * Credentials and other informations required to successfull execute the login
     * are provided by an callback handler instance.
     *
     * @param handler the handler.
     * @return AuthenticationContext.
     * @throws AuthenticationException if error occurs.
     */
    AuthenticationContext login(CallbackHandler handler) throws AuthenticationException;

    /**
     * Method performs a login with a given authentication context.
     * <p/>
     * Credentials and other informations required to successfull execute the login
     * are provided by an callback handler instance.
     *
     * @param handler the handler.
     * @param ctx     the ctx.
     * @return AuthenticationContext.
     * @throws AuthenticationException if error occurs.
     */
    AuthenticationContext login(CallbackHandler handler, AuthenticationContext ctx) throws AuthenticationException;

    /**
     * Method performs a logout.
     *
     * @param ctx the ctx.
     * @return AuthenticationContext.
     * @throws AuthenticationException if error occurs.
     */
    AuthenticationContext logout(AuthenticationContext ctx) throws AuthenticationException;

}