/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.authentication;

import java.io.Serializable;

/**
 * A UsernamePasswordCredential represents a credential combination from username and password.
 * 
 * @author Arne Broering, Marko Reiprecht
 */
public class UsernamePasswordCredential implements Credential, Serializable {

    // ------------------------------ FIELDS ------------------------------

    private static final long serialVersionUID = 576673930154464333L;

    private final String m_username;
    private final char[] m_password;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Constructor creates a new instance.
     * 
     * @param username
     *            the username.
     * @param password
     *            the password.
     */
    public UsernamePasswordCredential(final String username, final char[] password) {
        if (username == null) {
            throw new IllegalArgumentException("username must not null");
        }
        if (password == null) {
            throw new IllegalArgumentException("password must not null");
        }
        m_username = username;
        m_password = password;
    }

    /**
     * Constructor creates a new instance.
     * 
     * @param username
     *            the username.
     * @param password
     *            the password.
     */
    public UsernamePasswordCredential(final String username, final String password) {
        this(username, password == null ? new char[0] : password.toCharArray());
    }

    // --------------------- GETTER / SETTER METHODS ---------------------

    /**
     * Method gets the password.
     * 
     * @return char[].
     */
    public char[] getPassword() {
        return m_password;
    }

    /**
     * Method gets the username.
     * 
     * @return String.
     */
    public String getUsername() {
        return m_username;
    }
}
