/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.authentication;

import org.dom4j.DocumentFactory;
import org.dom4j.Element;
import org.dom4j.Node;
import org.dom4j.QName;
import org.n52.security.common.util.XMLUtilsDom4j;

/**
 * Describes possiblitiy to use an WAS ticket as authentication credential.
 * todo: describe better.
 */
public class WASAuthenticationMethod implements AuthenticationMethod {

    /**
     * URN identifying this method.
     */
    public static final String URN = "urn:opengeospatial:authNMethod:OWS:1.0:wauthns";

    private String m_name = "WAS";
    private String m_url;
    private String m_version = "1.1";

    /**
     * Constructor creates a new instance with empty url.
     */
    public WASAuthenticationMethod() {}


    /**
     * Constructor creates a new instance.
     *
     * @param name    the name of the WAS.
     * @param url     the url of the WAS.
     * @param version the version the Version of the WAS.
     */
    public WASAuthenticationMethod(final String name, final String url, final String version) {
        this.m_name = name;
        this.m_url = url;
        this.m_version = version;
    }


    /**
     * @see AuthenticationMethod#asDom4J()
     */
    public Node asDom4J() {
        DocumentFactory lFac = XMLUtilsDom4j.getDocFactory();
        Element lAuthnMethElem = lFac.createElement(new QName("AuthenticationMethod", XMLUtilsDom4j.sAuthnNamespace));
        lAuthnMethElem.addAttribute(new QName("type", XMLUtilsDom4j.sXsiNamespace), "authn:WASType");
        lAuthnMethElem.addAttribute("method", getURN());
        Element lAccServElem = lFac.createElement(
                new QName("AcceptedAuthenticationServiceList", XMLUtilsDom4j.sAuthnNamespace));
        lAuthnMethElem.add(lAccServElem);
        Element lAuthServElem = lFac.createElement(new QName("AuthenticationService", XMLUtilsDom4j.sAuthnNamespace));
        lAccServElem.add(lAuthServElem);
        Element lNameElem = lFac.createElement(new QName("Name", XMLUtilsDom4j.sAuthnNamespace));
        lNameElem.setText(getName());
        lAuthServElem.add(lNameElem);
        Element lVersionElem = lFac.createElement(new QName("Version", XMLUtilsDom4j.sAuthnNamespace));
        lVersionElem.setText(getVersion());
        lAuthServElem.add(lVersionElem);
        Element lOnlineResElem = lFac.createElement(new QName("OnlineResource", XMLUtilsDom4j.sAuthnNamespace));
        lOnlineResElem.addAttribute(new QName("type", XMLUtilsDom4j.sXlinkNamespace), "simple");
        lOnlineResElem.addAttribute(new QName("href", XMLUtilsDom4j.sXlinkNamespace), getUrl());
        lAuthServElem.add(lOnlineResElem);

        return lAuthnMethElem;
    }

    /**
     * Method gets the name.
     *
     * @return String.
     */
    public String getName() {
        return m_name;
    }

    /**
     * Method sets the name.
     *
     * @param name the name.
     */
    public void setName(final String name) {
        m_name = name;
    }

    /**
     * Method gets the url.
     *
     * @return String.
     */
    public String getUrl() {
        return m_url;
    }

    /**
     * Method sets the url.
     *
     * @param url the url.
     */
    public void setUrl(final String url) {
        m_url = url;
    }

    /**
     * Method gets the version.
     *
     * @return String.
     */
    public String getVersion() {
        return m_version;
    }

    /**
     * Method sets the version.
     *
     * @param version the version.
     */
    public void setVersion(final String version) {
        m_version = version;
    }

    /**
     * @see AuthenticationMethod#getURN()
     */
    public String getURN() {
        return URN;
    }

}
