/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.authentication.loginmodule;

import java.io.IOException;
import java.net.URL;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.apache.log4j.Logger;
import org.dom4j.Document;
import org.dom4j.DocumentException;
import org.dom4j.Node;
import org.n52.security.common.util.XMLUtilsDom4j;
import org.xml.sax.InputSource;

/**
 * @author JanDrewnak
 *
 */
public class FileLoginUserManager {

    private static Logger sLogger = Logger.getLogger(FileLoginUserManager.class);

    private Map m_userMap;

    private URL m_usersFileUrl;

    public FileLoginUserManager(final URL sUsersFileUrl) throws DocumentException, IOException {
        this.m_usersFileUrl = sUsersFileUrl;
        m_userMap = loadUsers();
    }

    private Map loadUsers() throws DocumentException, IOException {
        Document pUsersRepositoryDoc = XMLUtilsDom4j.read(new InputSource(m_usersFileUrl.openStream()));
        Map lReturnMap = new HashMap();
        List lUserNodes = pUsersRepositoryDoc.selectNodes("//users:User");
        for (Iterator iter = lUserNodes.iterator(); iter.hasNext();) {
            FileLoginUser tUser = new FileLoginUser((Node) iter.next());
            if (lReturnMap.put(tUser.getUsername(), tUser) != null) {
                sLogger.warn("Duplicate username: " + tUser.getUsername());
            }

        }
        return lReturnMap;
    }

    public FileLoginUser getUser(final String username) {
        boolean doesUsernameExist = m_userMap.containsKey(username);
        if (doesUsernameExist) {
            return (FileLoginUser) m_userMap.get(username);
        }
        return null;
    }

    public List getAllUsers() {
        List userList = new ArrayList();
        Set userSet = m_userMap.keySet();
        Iterator userIter = userSet.iterator();
        while (userIter.hasNext()) {
            userList.add(userIter.next());
        }
        return userList;

    }


    public Map getUserMap() {
        return new HashMap(m_userMap);
    }

}
