/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.authentication.principals;

import java.io.Serializable;

/**
 * Interface Scope represents a scope, e.g. an name of an application or an namespace or an urn.
 * It is used to define and reduce the visibility and validity of a name objects.
 * <p/>
 * It shall be possible to build chains of scopes, e.g. you can use scope instance to identify a special application and
 * then associate other scope instances with the previous created applicaton scope.
 * 
 * @author Marko Reiprecht
 *         Created on 16.09.2007
 * @version $Revision: $
 */
public interface Scope extends Serializable {

    /**
     * static final Field GLOBAL represents the GLOBAL-Scope,
     * it is returned in the {@link #getScope()} method to
     * indicate that there is no further parent.
     */
    Scope GLOBAL = new Scope() {
        /**
         * The serialVersionUID.
         * 
         * @see java.io.Serializable
         */
        private static final long serialVersionUID = -1L;

        /**
         * returns an empty String.
         * 
         * @return String.
         */
        public String getName() {
            return "";
        }

        /**
         * returns the GLOBAL Scope (this)
         * 
         * @return Scope.
         */
        public Scope getScope() {
            return this;
        }

        /**
         * @see java.lang.Object#toString()
         */
        public String toString() {
            return "::";
        }
    };

    /**
     * Gets the name of the scope.
     * 
     * @return String.
     */
    String getName();

    /**
     * Gets the 'parent' scope of this scope.
     * <p/>
     * This method must not return null. To indicate that no further scope exist the {@link #GLOBAL} scope shall
     * returned.
     * 
     * @return Scope.
     */
    Scope getScope();
}
