/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 * 
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 * 
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.attributes;

import java.io.Serializable;

/**
 * Class EmptyAttributeValue represents a 'null' or empty attribute value.
 * <p/>
 *
 * @author Marko Reiprecht
 *         Created on 26.03.2007
 * @version $Revision: 1748 $
 */
public class EmptyAttributeValue implements AttributeValue, Serializable {

    // ------------------------------ FIELDS ------------------------------

    /**
     * The type of an EmptyAttribute is 'null'.
     */
    public static final String TYPE_NAME = "null";

    /** Field serialVersionUID.  */
    private static final long serialVersionUID = -2196019278993823155L;

    // --------------------------- CONSTRUCTORS ---------------------------

    /**
     * Use {@link AttributeValue#EMPTY_VALUE}
     * to get an instance of this class.
     */
    protected EmptyAttributeValue() {}

    // ------------------------ INTERFACE METHODS ------------------------


    // --------------------- Interface AttributeValue ---------------------

    /**
     * This will always return null.
     *
     * @return null
     * @see AttributeValue#getUnspecifiedValue()
     */
    public Object getUnspecifiedValue() {
        return null;
    }

    /**
     * Returns {@link #TYPE_NAME}.
     *
     * @return a type name {@link #TYPE_NAME}.
     * @see AttributeValue#getTypeName()
     */
    public String getTypeName() {
        return TYPE_NAME;
    }
}
