/* Copyright (C) 2007 con terra GmbH (http://www.conterra.de)
 * All rights reserved
 *
 * $Id: $
 *
 * Originally created
 * by :     Marko Reiprecht
 * at :     16.10.2009 12:08:52
 */
package org.n52.security.common.crypto;

import java.math.BigInteger;
import java.security.cert.Certificate;

/**
 * Simple base class for decorator implementations of KeyPairProviders.
 * 
 * @author Marko Reiprecht
 */
public abstract class AbstractKeyPairProviderDecorator implements KeyPairProvider {

    private KeyPairProvider m_delegate;

    /**
     * Creates new instance.
     */
    public AbstractKeyPairProviderDecorator() {
    }

    /**
     * Creates new instance.
     * 
     * @param delegate
     */
    public AbstractKeyPairProviderDecorator(final KeyPairProvider delegate) {
        m_delegate = delegate;
    }

    /**
     * @return the delegate
     */
    public KeyPairProvider getDelegate() {
        return m_delegate;
    }

    /**
     * @param delegate
     *            the delegate to set
     */
    public void setDelegate(final KeyPairProvider delegate) {
        if (delegate == null) {
            throw new IllegalArgumentException("delegate must not null");
        }
        m_delegate = delegate;
    }

    /**
     * @see org.n52.security.common.crypto.KeyPairProvider#resolveByAlias(java.lang.String, char[])
     */
    public KeyPair resolveByAlias(final String alias, final char[] password) throws KeyPairResolvingException {
        return getDelegate().resolveByAlias(alias, password);
    }

    /**
     * @see org.n52.security.common.crypto.KeyPairProvider#resolveByCertificate(java.security.cert.Certificate, char[])
     */
    public KeyPair resolveByCertificate(final Certificate cert, final char[] password) throws KeyPairResolvingException {
        return getDelegate().resolveByCertificate(cert, password);
    }

    /**
     * @see org.n52.security.common.crypto.KeyPairProvider#resolveBySerialIssuer(java.lang.String, java.math.BigInteger,
     *      char[])
     */
    public KeyPair resolveBySerialIssuer(final String issuerDN, final BigInteger serial, char[] password)
            throws KeyPairResolvingException {
        return getDelegate().resolveBySerialIssuer(issuerDN, serial, password);
    }

}
