/* Copyright (C) 2007 con terra GmbH (http://www.conterra.de)
 * All rights reserved
 *
 * $Id: $
 *
 * Originally created
 * by :     Marko Reiprecht
 * at :     16.10.2009 13:21:32
 */
package org.n52.security.common.crypto;

import java.util.HashMap;
import java.util.Map;

/**
 * Wraps incomming alias names to aliasnames used in the decorated provider.
 * If the name can't be mapped the incomming names is given to the decorated provider.
 * 
 * @author Marko Reiprecht
 */
public class AliasMappingKeyProviderDecorator extends AbstractKeyPairProviderDecorator {

    /**
     * <String,String> map.
     */
    private Map m_aliasToKeyAliasMap = new HashMap();

    /**
     * @return the aliasToKeyAliasMap
     */
    public Map getAliasToKeyAliasMap() {
        return m_aliasToKeyAliasMap;
    }

    /**
     * It is espected that the incoming alias names are used as keys and the internal/outcomming alias names are used as
     * values.
     * 
     * @param aliasToKeyAliasMap
     *            the aliasToKeyAliasMap to set
     */
    public void setAliasToKeyAliasMap(final Map aliasToKeyAliasMap) {
        if (aliasToKeyAliasMap == null) {
            throw new IllegalArgumentException("aliasToKeyAliasMap must not null");
        }
        m_aliasToKeyAliasMap = aliasToKeyAliasMap;
    }

    /**
     * Creates new instance.
     * 
     * @param delegate
     */
    public AliasMappingKeyProviderDecorator() {
    }

    /**
     * Creates new instance.
     * 
     * @param delegate
     */
    public AliasMappingKeyProviderDecorator(final KeyPairProvider delegate) {
        super(delegate);
    }

    /**
     * @see org.n52.security.common.crypto.AbstractKeyPairProviderDecorator#resolveByAlias(java.lang.String, char[])
     */
    public KeyPair resolveByAlias(final String alias, final char[] password) throws KeyPairResolvingException {
        String newAlias = (String) getAliasToKeyAliasMap().get(alias);
        return super.resolveByAlias(newAlias != null ? newAlias : alias, password);
    }

}
