/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 24.07.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.crypto;

import org.n52.security.common.util.FileFinder;

/**
 * Class KeystoreKeyPairProviderBeanFactory constructs a KeystoreKeyPairProvider from it's properties.
 * It can be used within the security-config.xml or in a spring configuration.
 *
 * @author Marko Reiprecht
 *         Created on 24.07.2008
 * @version $Revision: $
 */
public class KeystoreKeyPairProviderBeanFactory {

    // ------------------------------ FIELDS ------------------------------

    private String m_keystoreType = "JKS";
    private String m_password = "";
    private String m_fileName = "/.keystore";

    // --------------------- GETTER / SETTER METHODS ---------------------

    /**
     * Method gets the fileName.
     *
     * @return String.
     */
    public String getFileName() {
        if (m_fileName == null || m_fileName.length() == 0) {
            throw new IllegalStateException("property <filename> not configured properly");
        }
        return m_fileName;
    }

    /**
     * Method sets the fileName.
     *
     * @param fileName the fileName.
     */
    public void setFileName(final String fileName) {
        m_fileName = fileName;
    }

    /**
     * Method gets the keyStoreType.
     *
     * @return String.
     */
    public String getKeystoreType() {
        if (m_keystoreType == null || m_keystoreType.length() == 0) {
            throw new IllegalStateException("property <keyStoreType> not configured properly");
        }
        return m_keystoreType;
    }

    /**
     * Method sets the keyStoreType.
     *
     * @param keystoreType the keyStoreType.
     */
    public void setKeystoreType(final String keystoreType) {
        m_keystoreType = keystoreType;
    }

    /**
     * Method gets the password.
     *
     * @return String.
     */
    public String getPassword() {
        if (m_password == null) {
            throw new IllegalStateException("property <password> not configured properly");
        }
        return m_password;
    }

    /**
     * Method sets the password.
     *
     * @param password the password.
     */
    public void setPassword(final String password) {
        m_password = password;
    }

    // -------------------------- OTHER METHODS --------------------------

    /**
     * Method creates a keystore provider.
     *
     * @return KeystoreKeyPairProvider.
     */
    public KeystoreKeyPairProvider create() {
        return new KeystoreKeyPairProvider(getKeystoreType(),
                                           new FileFinder(getFileName()).getInputStream(),
                                           getPassword().toCharArray());
    }
}
