/* Copyright (C) 2007 con terra GmbH (http://www.conterra.de)
 * All rights reserved
 *
 * $Id: $
 *
 * Originally created
 * by :     Marko Reiprecht
 * at :     13.10.2009 08:53:10
 */
package org.n52.security.decision;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Marko Reiprecht
 */
public class DecisionServiceChain implements DecisionService {

    private List m_decisionServices = new ArrayList();

    /**
     * Creates new instance.
     * 
     * @param decisionServices
     */
    public DecisionServiceChain() {
    }

    /**
     * Creates new instance.
     * 
     * @param decisionServices
     */
    public DecisionServiceChain(final Iterator decisionServices) {
        while (decisionServices.hasNext()) {
            m_decisionServices.add((DecisionService) decisionServices.next());
        }
    }

    public void add(final DecisionService decisionService) {
        if (decisionService == null) {
            throw new IllegalArgumentException("decisionService must not null");
        }
        m_decisionServices.add(decisionService);
    }

    public void remove(final DecisionService decisionService) {
        if (decisionService == null) {
            throw new IllegalArgumentException("decisionService must not null");
        }
        m_decisionServices.remove(decisionService);
    }

    /**
     * @see org.n52.security.decision.DecisionService#request(org.n52.security.decision.PDPRequestCollection)
     */
    public PDPResponseCollection request(final PDPRequestCollection reqCol) throws DecisionProcessingException {

        PDPRequestCollection openRequests = reqCol;
        Map allResponses = new LinkedHashMap();
        PDPResponseCollection lastResponse = null;
        for (Iterator serviceIt = m_decisionServices.iterator(); serviceIt.hasNext() && !openRequests.isEmpty(); openRequests =
            findOpenRequests(lastResponse, allResponses)) {
            DecisionService decisionService = (DecisionService) serviceIt.next();
            lastResponse = decisionService.request(openRequests);
        }
        // little optimization
        if (m_decisionServices.size() == 1 && lastResponse != null) {
            return lastResponse;
        }
        PDPResponseCollection response = new PDPResponseCollection();
        for (Iterator requests = reqCol.iterator(); requests.hasNext();) {
            PDPResponse resp = (PDPResponse) allResponses.get(requests.next());
            response.add(resp);
        }
        return response;
    }

    /**
     * Responsible for checking of open(undefined) requests and the filling of the allResponse map.
     * 
     * @param lastResponse
     *            the last response of a single decision service.
     * @param allResponses
     *            a insertion ordered map of request to responses.
     * @return all open (undefined) requests.
     */
    private PDPRequestCollection findOpenRequests(final PDPResponseCollection lastResponse,
                                                  final Map allResponses) {
        PDPRequestCollection reqcol = new PDPRequestCollection();
        for (Iterator respIt = lastResponse.iterator(); respIt.hasNext();) {
            PDPResponse resp = (PDPResponse) respIt.next();
            if (resp.isUndefined()) {
                reqcol.add(resp.getRequest());
            }
            allResponses.put(resp.getRequest(), resp);
        }
        return reqcol;
    }

}
